Learn R Programming

operators (version 0.1-8)

pattern: Pattern matching operators

Description

Set of convenience functions to handle strings and pattern matching. These are basically companion binary operators for the classic R function grep and regexpr.

Usage

x %~% rx
  x %!~% rx
  
  x %~*% rx
  x %!~*% rx

x %~+% rx x %!~+% rx

Value

%~% : gives a logical vector indicating which elements of x

match the regular expression rx. %!~% is the negation of

%~%

%~*% : gives a single logical indicating if all the elements of x are matching the regular expression rx. %!~*% is the negation of %~*%.

%~+% : gives a single logical indicating if any

element of x matches the regular expression rx. %!~+%

is the negation of %~+%.

Arguments

x

text to manipulate

rx

regular expression

Author

Romain Francois <[email protected]>

See Also

grep, gsub, %~|% for regular expression filters

Examples

Run this code
  txt <- c("arm","foot","lefroo", "bafoobar")
  txt %~% "foo"
  txt %!~% "foo"
  txt %~*% "foo"
  txt %~+% "foo"
  txt %!~*% "foo"
  txt %!~+% "foo"
  
  txt %~%   "[a-z]"
  txt %!~%  "[a-z]"
  txt %~*%  "[a-z]"
  txt %~+%  "[a-z]"
  txt %!~*% "[a-z]"
  txt %!~+% "[a-z]"
  
  
  cols <- colors()
  cols[ cols %~% "^blue" ]
  # see also %~|%
  
  
  ## needs perl regular expression for the \\d, see %but%
  with( options( operators.regexpr = "p" ), {
  	cols[ cols %!~% "\\d$" ]
  } )
  

Run the code above in your browser using DataLab