Learn R Programming

operators (version 0.2.0)

patternDivision: Divide by a pattern

Description

split a character vector by a regular expression

Usage

txt %/~% rx

Value

A character vector. For convenience, this function does not return a list as strsplit does.

Arguments

txt

text to manipulate

rx

regular expression

Details

%/~% uses strsplit to split the strings. Logical arguments of strsplit can be indirectly modified using the operators.strsplit option declared as part of this package. For example, it uses perl regular expressions by default. See %but% for a description.

Examples

Run this code
"Separate these  words by spaces" %/~% " +"

 ### From ?strsplit
 unlist(strsplit("a.b.c", "\\\\."))
 "a.b.c" %/~% "\\\\."

Run the code above in your browser using DataLab