powered by
The operator prints the R object into a temporay file and then executes the unix command though a pipe
print
pipe
r %|% u
An object of S3-class unixoutput. The print method for unixoutput objects simply cat the string.
unixoutput
cat
Any R object
character string representing the unix command
if (FALSE) { rnorm(30) %|% 'head -n2' rnorm(30) %|% 'sed "s/^ *\\\\[[0-9]*\\\\]//g" ' }
Run the code above in your browser using DataLab