powered by
Creates string decorators by repeating a pattern either a given number of times or so that it takes a given number of character
txt %x=% n txt %x=|% length.out strrep( txt, n, length.out=getOption("width") )
A character string
Pattern to repeat
Number of times to repeat the pattern
number of character the output should be
Romain Francois <[email protected]>
paste, sprintf, rep
paste
sprintf
rep
"=" %x=% 80 "<-+->" %x=|% 80 strrep( ".-", n = 10 ) strrep( ".-", length.out = 50 ) strrep( ".-" )
Run the code above in your browser using DataLab